@@ -1,4 +1,4 @@
-#ident "$Id: class1lib.c,v 4.4 1998/01/22 07:28:49 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: class1lib.c,v 4.20 2006/10/25 10:56:41 gert Exp $ Copyright (c) Gert Doering"
 
 /* class1lib.c
  *
@@ -10,9 +10,11 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 #include <signal.h>
 #include <ctype.h>
+#include <errno.h>
 
 #include "mgetty.h"
 #include "fax_lib.h"
@@ -27,12 +29,14 @@
 
 #define F1LID 20
 static char fax1_local_id[F1LID];	/* local system ID */
-static int fax1_min, fax1_max;		/* min/max speed */
+static int fax1_min = 2400,		/* min/max speed */
+	   fax1_max = 14400;
 static int fax1_res;			/* flag for normal resolution */
 
-       int fax1_dis;			/* "X"-bit (last received DIS) */
+       uch fax1_dis = 0x00;		/* "X"-bit (last received DIS) */
 
-static int fax1_fth, fax1_ftm;		/* local carrier capabilities */
+static int fax1_fth, fax1_ftm,		/* modem carrier capabilities */
+	   fax1_frh, fax1_frm;
 
 /* symbolic constants for capability check
  */
@@ -67,7 +71,20 @@ struct fax1_btable fax1_btable[] = {
  * (increment == fallback after FTT!)
  */
 struct fax1_btable * dcs_btp = fax1_btable;
-		      
+
+/* table of bits-to-scan line time mappings, index = bits
+ */
+struct fax1_st_table { int st; int ms_n; int ms_f; char * txt; };
+struct fax1_st_table fax1_st_table[8] = {
+	/* ST, ms normal, ms fine                  bits    */
+	{ 5, 20, 20, " 20ms" },			/* 0 = 000 */
+	{ 1,  5,  5, " 5ms" },			/* 1 = 100 */
+	{ 3, 10, 10, " 10ms" },			/* 2 = 010 */
+	{ 4, 20, 10, " 20/10ms" },		/* 3 = 110 */
+	{ 7, 40, 40, " 40ms" },			/* 4 = 001 */
+	{ 6, 40, 20, " 40/20ms" },		/* 5 = 101 */
+	{ 2, 10,  5, " 10/5ms" },		/* 6 = 011 */
+	{ 0,  0,  0, " 0ms" }};			/* 7 = 111 */
 
 int fax1_set_l_id _P2( (fd, fax_id), int fd, char * fax_id )
 {
@@ -111,6 +128,17 @@ static int fax1_carriers _P1((p), char * p )
     return cbits;
 }
 
+/* step down max speed (at retrain time)
+ */
+void fax1_reduce_max _P0(void)
+{
+    if ( dcs_btp->speed > 2400 )
+    { 
+	fax1_max = dcs_btp->speed - 2400; 
+	lprintf( L_NOISE, "reduce max speed to %d", fax1_max );
+    }
+}
+
 /* set fine/normal resolution flags and min/max transmission speed
  * including finding out maximum speed modem can do!
  */
@@ -121,42 +149,53 @@ int fax1_set_fdcc _P4( (fd, fine, max, min),
 
     lprintf( L_MESG, "fax1_set_fdcc: fine=%d, max=%d, min=%d", fine, max, min );
 
-    fax1_max = max/2400 -1;
-    fax1_min = (min>2400)? min/2400 -1: 0;
+    fax1_max = max;
+    fax1_min = min;
     fax1_res = fine;
 
-    lprintf( L_MESG, "max: %d, min: %d", fax1_max, fax1_min );
+    if ( fax1_min == 0 ) fax1_min=2400;
 
     if ( fax1_max < fax1_min ||
-	 fax1_max < 1 || fax1_max > 5 ||
-	 fax1_min < 0 || fax1_min > 5 ) 
+	 fax1_max < 2400 || fax1_max > 14400 ||
+	 fax1_min < 2400 || fax1_min > 14400 ) 
     {
-	fax1_min = 0; fax1_max = 5;
-	return ERROR;
+	lprintf( L_WARN, "min/max values (%d/%d) out of range, use 2400/14400", min, max );
+	fax1_min = 2400; fax1_max = 14400;
     }
 
     if ( fax1_res < 0 || fax1_res > 1 ) 
     {
+	lprintf( L_WARN, "fax1_res (%d) out of range, use fine (1)", fax1_res );
 	fax1_res = 1;
-	return ERROR;
     }
 
+#if 0			/* we don't support anything but AT+FTH=3 yet */
     p = mdm_get_idstring( "AT+FTH=?", 1, fd );
     fax1_fth = fax1_carriers( p );
     lprintf( L_MESG, "modem can send HDLC headers: %03x", fax1_fth );
+#else
+    fax1_fth = 001;
+#endif
 
     p = mdm_get_idstring( "AT+FTM=?", 1, fd );
     fax1_ftm = fax1_carriers( p );
     lprintf( L_MESG, "modem can send page data: %03x", fax1_ftm );
 
+#if 0			/* we don't support anything but AT+FRH=3 yet */
+    p = mdm_get_idstring( "AT+FRH=?", 1, fd );
+    fax1_frh = fax1_carriers( p );
+    lprintf( L_MESG, "modem can recv HDLC headers: %03x", fax1_fth );
+#else
+    fax1_frh = 001;
+#endif
+
+    p = mdm_get_idstring( "AT+FRM=?", 1, fd );
+    fax1_frm = fax1_carriers( p );
+    lprintf( L_MESG, "modem can recv page data: %03x", fax1_ftm );
+
     return NOERROR;
 }
 
-int fax1_set_bor _P2( (fd, bor), int fd, int bor )
-{
-    /*!!! TODO - what TODO ??! */
-    return NOERROR;
-}
 
 /* timeout handler
  */
@@ -193,8 +232,14 @@ int fax1_receive_frame _P4 ( (fd, carrier, timeout, framebuf),
     {
     char cmd[20];
 	sprintf( cmd, "AT+FRH=%d", carrier );
-	fax_send( cmd, fd );
-	/*!!! DO NOT USE fax_send (FAX_COMMAND_DELAY) */
+
+	/*!!! TOOD: DO NOT USE fax_send (FAX_COMMAND_DELAY) */
+
+	/* normally, fax_send() can only fail if something is really 
+	 * messed up with the serial port, e.g. "stuck flow control"
+	 */
+	if ( fax_send( cmd, fd ) == ERROR )
+		    { alarm(0); return ERROR; }
 
 	/* wait for CONNECT/NO CARRIER */
 	line = mdm_get_line( fd );
@@ -204,7 +249,17 @@ int fax1_receive_frame _P4 ( (fd, carrier, timeout, framebuf),
 	if ( line == NULL || strcmp( line, "CONNECT" ) != 0 )
 	{
 	    alarm(0);
-	    lprintf( L_WARN, "fax1_receive_frame: no carrier (%s)", line );
+	    if ( line == NULL )
+	    {
+		char cancel_str[] = { CAN };
+		lprintf( L_WARN, "fax1_receive_frame: no carrier (timeout), send CAN" );
+		write( fd, cancel_str, 1 );
+		alarm(2);
+		line = mdm_get_line( fd );
+		alarm(0);
+	    }
+	    else
+		lprintf( L_WARN, "fax1_receive_frame: no carrier (%s)", line );
 	    return ERROR;
 	}
     }
@@ -219,11 +274,11 @@ int fax1_receive_frame _P4 ( (fd, carrier, timeout, framebuf),
     {
         if ( mdm_read_byte( fd, &c ) != 1 )
 	{
-	    lprintf( L_ERROR, "fax1_get_frame: cannot read byte, return" );
+	    lprintf( L_ERROR, "fax1_receive_frame: cannot read byte, return" );
 	    rc = ERROR; break;
 	}
 
-	/*!!!! ERROR statt Frame-Daten erkennen */
+	/*!!!! TODO: CONNECT/ERROR statt Frame-Daten erkennen */
 
 	lputc( L_NOISE, c );
 
@@ -238,7 +293,7 @@ int fax1_receive_frame _P4 ( (fd, carrier, timeout, framebuf),
 	/* enough room? */
 	if ( count >= FRAMESIZE-5 )
 	{
-	    lprintf( L_ERROR, "fax1_get_frame: too many octets in frame" );
+	    lprintf( L_ERROR, "fax1_receive_frame: too many octets in frame" );
 	    rc = ERROR; break;
 	}
 
@@ -265,16 +320,17 @@ int fax1_receive_frame _P4 ( (fd, carrier, timeout, framebuf),
 	framebuf[count++] = c;
     }
 
-    /*!!! nur, wenn nicht schon "ERROR" !!!*/
-
-    /* now read OK / ERROR response codes */
-    line = mdm_get_line( fd );
-
-    if ( line == NULL ||			/* timeout ... */
-         strcmp( line, "ERROR" ) == 0 )		/* or FCS error */
+    /* now read OK / ERROR response codes (only if we're still happy) */
+    if ( rc != ERROR )
     {
-	lprintf( L_MESG, "fax1_receive_frame: dropping frame" );
-        rc = ERROR;
+	line = mdm_get_line( fd );
+
+	if ( line == NULL ||				/* timeout ... */
+	     strcmp( line, "ERROR" ) == 0 )		/* or FCS error */
+	{
+	    lprintf( L_MESG, "fax1_receive_frame: dropping frame" );
+	    rc = ERROR;
+	}
     }
 
     /* turn off alarm */
@@ -282,18 +338,19 @@ int fax1_receive_frame _P4 ( (fd, carrier, timeout, framebuf),
 
     if ( rc > 0 )
     {
-        fax1_dump_frame( framebuf, count );
+        fax1_dump_frame( '<', framebuf, count );
     }
 
     return rc;
 }
 
 
-void fax1_dump_frame _P2((frame, len), unsigned char * frame, int len)
+void fax1_dump_frame _P3((io, frame, len), 
+			  char io, unsigned char * frame, int len)
 {
 int fcf = frame[1];
 
-    lprintf( L_MESG, "frame type: 0x%02x  len: %d  %s%s",
+    lprintf( L_MESG, "%c frame type: 0x%02x  len: %d  %s%s", io,
                       fcf, len, frame[0]&0x10? "final": "non-final",
 		      (fcf & 0x0e) && ( fcf & 0x01 ) ? " X": "");
 
@@ -320,6 +377,14 @@ int fcf = frame[1];
 	    lprintf( L_NOISE, "RTP" ); break;
 	case T30_RTN:
 	    lprintf( L_NOISE, "RTN" ); break;
+
+	case T30_EOM:
+	    lprintf( L_NOISE, "EOM" ); break;
+	case T30_MPS:
+	    lprintf( L_NOISE, "MPS" ); break;
+	case T30_EOP:
+	    lprintf( L_NOISE, "EOP" ); break;
+
 	case T30_DCN:
 	    lprintf( L_NOISE, "DCN" ); break;
 
@@ -348,26 +413,17 @@ int fcf = frame[1];
             switch( frame[4] & 0x03 )
 	    {
 	        case 0x00: lputs( L_NOISE, " 215mm" ); break;
-		case 0x01: lputs( L_NOISE, " 215+255+303" ); break;
-		case 0x02: lputs( L_NOISE, " 215+255" ); break;
+		case 0x02: lputs( L_NOISE, " 215+255+303" ); break;
+		case 0x01: lputs( L_NOISE, " 215+255" ); break;
 	    }
 	    switch( (frame[4]>>2) & 0x03 )
 	    {
 	        case 0x00: lputs( L_NOISE, " A4" ); break;
-		case 0x01: lputs( L_NOISE, " unlim" ); break;
-		case 0x02: lputs( L_NOISE, " A4+B4" ); break;
-	    }
-	    switch( (frame[4]>>4) & 0x07 )
-	    {
-	        case 0x00: lputs( L_NOISE, " 20ms" ); break;
-	        case 0x01: lputs( L_NOISE, " 40ms" ); break;
-	        case 0x02: lputs( L_NOISE, " 10ms" ); break;
-	        case 0x04: lputs( L_NOISE, " 5ms" ); break;
-	        case 0x03: lputs( L_NOISE, " 5/10ms" ); break;
-	        case 0x06: lputs( L_NOISE, " 10/20ms" ); break;
-	        case 0x05: lputs( L_NOISE, " 20/40ms" ); break;
-	        case 0x07: lputs( L_NOISE, " 0ms" ); break;
+		case 0x02: lputs( L_NOISE, " unlim" ); break;
+		case 0x01: lputs( L_NOISE, " A4+B4" ); break;
 	    }
+	    lputs( L_NOISE, fax1_st_table[ (frame[4]>>4) & 0x07 ].txt );
+
 	    if ( ( frame[4] & 0x80 ) == 0 ) break;	/* extent bit */
 
 	    if ( frame[5] & 0x04 ) lputs( L_NOISE, " ECM" );
@@ -379,28 +435,99 @@ int fcf = frame[1];
 
 	    break;
 	case T30_DCS:
-	    lprintf( L_NOISE, "DCS:" ); break;
+	    lprintf( L_NOISE, "DCS:" );
+
+	    if ( frame[2] & 0x40 ) lputs( L_NOISE, " V8" );
+	    lputs( L_NOISE, frame[2] & 0x80 ? " 64": " 256" );
+
+	    if ( frame[3] & 0x02 ) lputs( L_NOISE, " RCV!" );
+
+	    switch( (frame[3] >> 2) &0x0f )
+	    {
+	        case 0x00: lputs( L_NOISE, " V27ter_2400" ); break;
+	        case 0x02: lputs( L_NOISE, " V27ter_4800" ); break;
+	        case 0x01: lputs( L_NOISE, " V29_9600" ); break;
+	        case 0x03: lputs( L_NOISE, " V29_7200" ); break;
+	        case 0x04: lputs( L_NOISE, " V33_14400" ); break;
+	        case 0x06: lputs( L_NOISE, " V33_12000" ); break;
+	        case 0x08: lputs( L_NOISE, " V17_14400" ); break;
+	        case 0x0a: lputs( L_NOISE, " V17_12000" ); break;
+	        case 0x09: lputs( L_NOISE, " V17_9600" ); break;
+	        case 0x0b: lputs( L_NOISE, " V17_7200" ); break;
+		default:   lputs( L_NOISE, " V.???" ); break;
+	    }
+
+	    if ( frame[3] & 0x40 ) lputs( L_NOISE, " 200!" );
+	    if ( frame[3] & 0x80 ) lputs( L_NOISE, " 2D!" );
+
+            switch( frame[4] & 0x03 )
+	    {
+	        case 0x00: lputs( L_NOISE, " 1728/215mm" ); break;
+		case 0x02: lputs( L_NOISE, " 2432/303mm" ); break;
+		case 0x01: lputs( L_NOISE, " 2048/255mm" ); break;
+	    }
+	    switch( (frame[4]>>2) & 0x03 )
+	    {
+	        case 0x00: lputs( L_NOISE, " A4" ); break;
+		case 0x02: lputs( L_NOISE, " unlim" ); break;
+		case 0x01: lputs( L_NOISE, " B4" ); break;
+	    }
+	    lputs( L_NOISE, fax1_st_table[ (frame[4]>>4) & 0x07 ].txt );
+
+	    if ( ( frame[4] & 0x80 ) == 0 ) break;	/* extent bit */
+
+	    if ( frame[5] & 0x04 ) lputs( L_NOISE, " ECM" );
+	    if ( frame[5] & 0x40 ) lputs( L_NOISE, " T.6" );
+	    if ( ( frame[5] & 0x80 ) == 0 ) break;	/* extent bit */
+
+	    if ( ( frame[6] & 0x80 ) == 0 ) break;	/* extent bit */
+	    /* the next bytes specify 300/400 dpi, color fax, ... */
+
+	    break;
+	default:
+	    lprintf( L_NOISE, "frame FCF 0x%02x not yet decoded", fcf );
     }
 }
 
 /* send arbitrary frame
  */
 int fax1_send_frame _P4( (fd, carrier, frame, len), 
-                         int fd, int carrier, char * frame, int len )
+                         int fd, int carrier, uch * frame, int len )
 {
 char * line;
-static carrier_active = -1;		/* inter-frame marker */
+static int carrier_active = -2;		/* inter-frame marker */
 uch dle_buf[FRAMESIZE*2+2];		/* for DLE-coded frame */
 int r,w;
 
-    /* send AT+FTH=3, wait for CONNECT 
-     * (but only if we've not sent an non-final frame befor!)
+    fax1_dump_frame( '>', frame, len );
+
+    /* this should never take more than a few msec, so the 10s timeout
+     * is more a safeguard for modem lockups, implementation mistakes, etc.
+     * - make sure we're not getting stuck in protocol loops
      */
+    alarm(10);
+
+    /* send AT+FTH=3, wait for CONNECT 
+     * (but only if we've not sent an non-final frame before!)
+     */
+
+    /* catch internal out-of-sync condition ('canthappen')
+     * (this is OK for the very first frame sent in receive mode - ugly, yes)
+     */
+    if ( carrier == T30_CAR_SAME && carrier_active == -1 )
+    {
+	errno = EINVAL;
+	lprintf( L_ERROR, "fax1_send_frame: internal error - no carrier, but T30_CAR_SAME requested" );
+	return ERROR;
+    }
+
     if ( carrier > 0 && carrier_active != carrier )
     {
     char cmd[20];
+
 	sprintf( cmd, "AT+FTH=%d", carrier );
-	fax_send( cmd, fd );		/*!!!!! NOOOO */
+	if ( fax_send( cmd, fd ) == ERROR )
+		    { alarm(0); carrier_active=-1; return ERROR; }
 
 	/* wait for CONNECT/NO CARRIER */
 	line = mdm_get_line( fd );
@@ -418,10 +545,12 @@ int r,w;
 	carrier_active=carrier;
     }
 
-    fax1_dump_frame( frame+1, len-1 );
+    /* first 0xff is mandatory, but not passed by caller */
+    dle_buf[0] = 0xff;
+    w=1;
 
     /* send <DLE> encoded frame data */
-    for( r=w=0; r<len; r++ )
+    for( r=0; r<len; r++ )
     {
         if ( frame[r] == DLE ) { dle_buf[w++] = DLE; }
 	dle_buf[w++] = frame[r];
@@ -430,7 +559,7 @@ int r,w;
     /* end-of-frame: <DLE><ETX> */
     dle_buf[w++] = DLE; dle_buf[w++] = ETX;
 
-    lprintf( L_JUNK, "fax1sf: %d/%d", len, w );
+    lprintf( L_JUNK, "fax1_send_frame: %d/%d", len+1, w );
 
     if ( write( fd, dle_buf, w ) != w )
     {
@@ -448,51 +577,81 @@ int r,w;
      * man OHNE neues AT+FTH *SOFORT* weitersenden!
      */
     line = mdm_get_line( fd );
-    lprintf( L_NOISE, "fax_send_frame: got '%s'", line );
+    lprintf( L_NOISE, "fax1_send_frame: frame sent, got '%s'", line );
 
-    if ( frame[1] & T30_FINAL )
+    if ( frame[0] & T30_FINAL )
     {
         carrier_active = -1;		/* carrier is off */
 	lprintf( L_NOISE, "carrier is off - OK='%s'", line );
     }
 
+    /* as we're sending, we shouldn't see NO CARRIER response - but this
+     * can happen, e.g. when the modem notices a remote hangup (ISDN etc.)
+     */
+    if ( line == NULL || strcmp( line, "NO CARRIER" ) == 0 )
+    {
+	lprintf( L_WARN, "fax1_send_frame: unexpected post-frame string '%s', assuming carrier off", line? line: "(null)" );
+	carrier_active = -1;
+	return ERROR;
+    }
+
 #if 0
     if ( line != NULL && strcmp( line, "CONNECT" ) == 0 )
     {
 	line = mdm_get_line( fd );
-	lprintf( L_NOISE, "fax_send_carrier: got '%s'", line );
+	lprintf( L_NOISE, "fax1_send_frame(2): got '%s'", line );
     }
 #endif
 
     return NOERROR;
 }
 
-/* send "disconnect now" frame 
+/* send simple frame, consisting only of FCF and no arguments
+ * (non-final frame)
+ */
+int fax1_send_simf_nonfinal _P3( (fd, carrier, fcf), 
+                                 int fd, int carrier, uch fcf )
+{
+uch frame[2];
+   frame[0] = 0x03;
+   frame[1] = fcf;
+   return fax1_send_frame( fd, carrier, frame, 2 );
+}
+
+/* send simple frame, consisting only of FCF and no arguments
+ * (final frame)
+ */
+int fax1_send_simf_final _P3( (fd, carrier, fcf), 
+                              int fd, int carrier, uch fcf )
+{
+uch frame[2];
+   frame[0] = 0x03 | T30_FINAL;
+   frame[1] = fcf;
+   return fax1_send_frame( fd, carrier, frame, 2 );
+}
+
+/* send "disconnect now" frame (DCN), and move internal state to "game over"
  * Note: this is always a "final" frame
  */
-int fax1_send_dcn _P1((fd), int fd )
+int fax1_send_dcn _P2((fd, code), int fd, int code )
 {
-    char frame[] = { 0xff, 0x13, T30_DCN };
-
-    frame[2] |= fax1_dis;		/* set "X"-Bit if needed */
-    fax_hangup = TRUE;
-
-    return fax1_send_frame( fd, 3, frame, sizeof(frame) );
+    if ( code != -1 )
+        { fax_hangup_code = code; fax_hangup = TRUE; }
+    return fax1_send_simf_final( fd, T30_CAR_V21, T30_DCN|fax1_dis );
 }
 
 /* send local identification (CSI, CIG or TSI) 
  * Note: "final" bit is never set, as these frames are always optional.
  */
-int fax1_send_idframe _P2((fd,fcf), int fd, int fcf )
+int fax1_send_idframe _P3((fd,fcf,carrier), int fd, uch fcf, int carrier)
 {
-    unsigned char frame[F1LID+3];
+    unsigned char frame[F1LID+2];
 
-    frame[0] = 0xff;
-    frame[1] = 0x03;
-    frame[2] = fcf;
-    memcpy( &frame[3], fax1_local_id, F1LID );
+    frame[0] = 0x03;
+    frame[1] = fcf;
+    memcpy( &frame[2], fax1_local_id, F1LID );
 
-    return fax1_send_frame( fd, 3, frame, sizeof(frame) );
+    return fax1_send_frame( fd, carrier, frame, sizeof(frame) );
 }
 
 void fax1_copy_id _P1((frame), uch * frame )
@@ -517,6 +676,66 @@ char c;
     lprintf( L_MESG, "fax_id: '%s'", fax_remote_id );
 }
 
+/* set local capabilities in DIS frame, announce to remote sender
+ */
+int fax1_send_dis _P1( (fd), int fd )
+{
+uch frame[FRAMESIZE];
+int speedbits = 0;
+int r_flags;
+struct fax1_btable * dis_btp = fax1_btable;
+
+    /* start with modem capabilities, restrain by FDCC values */
+    r_flags = fax1_frm;
+    while( dis_btp->speed > 2400 )
+    {
+	if ( dis_btp->speed < fax1_min || dis_btp->speed > fax1_max )
+	{
+	    r_flags &= ~(dis_btp->flag);
+	    lprintf( L_NOISE, "fax1_dis: %d out of range -> r_flags=%03x", dis_btp->speed, r_flags );
+	}
+	dis_btp++;
+    }
+
+    /* some devices advertise V.17, but it doesn't work - so provide override
+     * switch via modem_quirks that unconditionally turns off V.17
+     */
+    if ( modem_quirks & MQ_C1_NO_V17 ) r_flags &= ~V17;
+
+
+    /* this is a bit messy, but I don't know a really elegant way to
+     * use the fax1_btable structure for that  (see T.30, Table 2, p.46)
+     */
+    if ( (r_flags & V17) && (r_flags & V29) && (r_flags & V27ter) )
+    {
+	speedbits = 0x2c;		/* 1101 */
+    }
+    else 
+    {
+	if ( r_flags & V27t_4800 ) { speedbits |= 0x08; /* 0100 */ }
+	if ( r_flags & V29 )       { speedbits |= 0x04; /* 1000 */ }
+    }
+
+    lprintf( L_NOISE, "fax1_dis: r_flags=%03x -> speedbits=0x%02x",
+                      r_flags, speedbits );
+
+    /* DIS is always final frame */
+    frame[0] = 0x03 | T30_FINAL;
+    frame[1] = T30_DIS;
+
+    frame[2] = 0x00;		/* bits 1..8: group 1/2 - unwanted */
+    frame[3] = 0x00 |		/* bit 9: can transmit - TODO: polling! */
+	       0x02 |           /* bit 10: can receive */
+	       speedbits |	/* bit 11..14: receive rates - TODO!! */
+	       ((fax1_res&1) <<6) |	/* bit 15: can fine */
+	       0x00;		/* bit 16: can 2D */
+    frame[4] = 0x08 |		/* bits 17..20 = 215mm width, unlim. length */
+               0x70 |		/* bits 21..23 = 0ms scan time */
+	       0x00;		/* bit 24: extend bit - final */
+
+    return fax1_send_frame( fd, T30_CAR_SAME, frame, 5 );
+}
+
 /* parse incoming DIS frame, set remote capability flags
  */
 
@@ -569,8 +788,7 @@ void fax1_parse_dis _P1((frame), uch * frame )
     remote_cap.ln = ( frame[2] >> 2 ) & 0x03;
 
     /* bit 21-23: minimum scan line time */
-    /*!!! UNIMPLEMENTED */
-    remote_cap.st = ( frame[2] >> 4 ) & 0x07;
+    remote_cap.st = fax1_st_table[ (frame[2] >> 4) & 0x07 ].st;
 
     if ( frame[2] & 0x80 )	/* extend bit */
     {
@@ -586,33 +804,112 @@ void fax1_parse_dis _P1((frame), uch * frame )
 			remote_cap.bf, remote_cap.st );
 }
 
-int fax1_send_dcs _P2((fd, speed), int fd, int speed )
+int fax1_send_dcs _P2((fd, s_time), int fd, int s_time )
 {
 uch framebuf[FRAMESIZE];
+int i;
 
     /* find baud/carrier table entry that has a speed not over
      * "speed", and that uses a modulation scheme supported by both
      * the local and remote modem
      */
-    while( dcs_btp->speed > speed ||
-           ( dcs_btp->flag & fax1_ftm & remote_cap.br ) == 0 ) dcs_btp++;
+    dcs_btp = fax1_btable;
+
+    while( dcs_btp->speed > 2400 &&
+	   ( dcs_btp->speed > fax1_max ||
+            ( dcs_btp->flag & fax1_ftm & remote_cap.br ) == 0 ) ) dcs_btp++;
     
     lprintf( L_NOISE, "+DCS: 1,%03x", dcs_btp->flag );
 
     /*!!! calculate ALL values from DIS and to-be-sent page */
-    framebuf[0] = 0xff;			/* sync */
-    framebuf[1] = 0x03 | T30_FINAL;	/* DCS is always final frame */
-    framebuf[2] = fax1_dis | T30_DCS;	/* FCF */
-    framebuf[3] = 0;			/* bits 1..8 */
-    framebuf[4] = 0x02 |		/* bit 10: receiver operation */
+    framebuf[0] = 0x03 | T30_FINAL;	/* DCS is always final frame */
+    framebuf[1] = fax1_dis | T30_DCS;	/* FCF */
+    framebuf[2] = 0;			/* bits 1..8 */
+    framebuf[3] = 0x02 |		/* bit 10: receiver operation */
                   dcs_btp->dcs_bits |	/* bits 11..14: signalling rate */
 		  ((fax1_res&remote_cap.vr)<<6) | /* bit 15: fine mode */
 		  0x00;			/* bit 16: 2D */
-    framebuf[5] = 0x00 |		/* bit 17+18: 215 mm width */
+    framebuf[4] = 0x00 |		/* bit 17+18: 215 mm width */
     		  0x04 |		/* bit 19+20: B4 length */
-		  0x70 |		/* bits 21-23: scan line time */
+		  0x00 |		/* bits 21-23: scan line time */
 		  0x00;			/* bit 24: extend bit - final */
-    return fax1_send_frame( fd, 3, framebuf, 6 );
+
+    /* calculate correct bit settings for scan line time (bits 21-23) */
+    for( i=0;i<=7;i++ )
+    {
+	if ( fax1_st_table[i].ms_n == s_time )
+		{ framebuf[4] |= i<<4; break; }
+    }
+    return fax1_send_frame( fd, T30_CAR_V21, framebuf, 5 );
+}
+
+/* parse incoming DCS frame
+ * put communication parameters into global variables (dcs_btp, fax_par_d)
+ */
+/* TODO: error handling? "I don't understand this -> DCN" */
+void fax1_parse_dcs _P1((frame), uch *frame)
+{
+    /* bit rate + modulation requested (bits 11..14) */
+    dcs_btp = fax1_btable;
+    while( dcs_btp->speed > 2400 &&
+	   dcs_btp->dcs_bits != (frame[3] & 0x3c) ) dcs_btp++;
+
+    fax_par_d.br = dcs_btp->speed/2400 - 1;
+
+    /* fine resolution: bit 15 (98/196 lpi) */
+    fax_par_d.vr = ( frame[3] & 0x40 )? 1: 0;
+
+    /* 2D: bit 16 (1D/2D mod read) */
+    fax_par_d.df = ( frame[3] & 0x80 )? 1: 0;
+
+    /* page width: bits 17+18 (byte 4, bits 0+1) */
+    fax_par_d.wd = frame[4] & 0x03;
+
+    /* page length: bits 19+20 */
+    fax_par_d.ln = (frame[4] >> 2 ) & 0x03;
+
+    /* scan line time: bits 21-23 */
+    fax_par_d.st = fax1_st_table[ (frame[4] >> 4) & 0x07 ].st;
+
+    /* extend bit? */
+    if ( ( frame[4] && 0x80 ) == 0 ) goto done;
+
+    /* ECM - TODO */
+    
+done:
+    lprintf( L_NOISE, "DCS: speed=%d, flag=%03x", 
+	     dcs_btp->speed, dcs_btp->flag );
+}
+
+int fax1_init_FRM _P2((fd,carrier), int fd, int carrier )
+{
+    char cmd[20];
+    char *line;
+    int timeout = 30;
+
+    /* TODO: is this sufficient timeout handling? */
+    if ( timeout > 0 )
+    {
+	signal( SIGALRM, fax1_sig_alarm );
+        alarm( (timeout/10)+1 );
+    }
+
+    sprintf( cmd, "AT+FRM=%d", carrier );
+    if ( fax_send( cmd, fd ) )
+		{ alarm(0); return ERROR; }
+
+    /* wait for CONNECT/NO CARRIER */
+    line = mdm_get_line( fd );
+    if ( line != NULL && strcmp( line, cmd ) == 0 )
+		{ line = mdm_get_line( fd ); }		/* skip echo */
+
+    alarm(0);
+    if ( line == NULL || strcmp( line, "CONNECT" ) != 0 )
+    {
+	lprintf( L_WARN, "fax1_init_FRM: no carrier (%s)", line );
+	return ERROR;
+    }
+    return NOERROR;
 }
 
 #endif /* CLASS1 */ 
