@@ -1,4 +1,4 @@
-#ident "@(#)cnd.c	$Id: cnd.c,v 4.22 2001/10/21 15:02:28 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
+#ident "@(#)cnd.c	$Id: cnd.c,v 4.26 2005/04/17 11:55:43 gert Exp $ Copyright (c) 1993 Gert Doering/Chris Lewis"
 
 #include <stdio.h>
 #include <string.h>
@@ -81,6 +81,9 @@ struct cndtable cndtable[] =
     {"TIME=",			&CallTime},
     {"NMBR=",			&CallerId},
     {"NAME=",			&CallName},
+    /* Digi DataFire RAS / Patton 2977 can also report dialed number */
+    /* (if AT#CID=10 is set, contributed by Edwin Groothuis) */
+    {"NDID=",			&CalledNr},
 
     /* yet another incompatible modem... */
     {"CALLER'S NUMBER: ",	&CallerId},
@@ -94,6 +97,9 @@ struct cndtable cndtable[] =
     /* Swedish Telia/ZyXEL Omni 52k - Torulf Lundgren, torulf@upsys.se */
     {"Diverting number:",       &CallerId},
 
+    /* FALCOM A2D gsm modem - Andreas Barth, debian bug */
+    {"+CLIP: ",			&CallerId},
+
     {NULL}
 };
     
@@ -152,8 +158,17 @@ cndfind _P1((str), char *str)
 	    }
 	    else	/* normal case */
 	    {
-		*(cp->variable) = malloc(strlen(str) - len + 1);
+		*(cp->variable) = p = malloc(strlen(str) - len + 1);
 		(void) strcpy(*(cp->variable), str+len);
+
+		/* nuke quotes and non-printable characters (some of this 
+		 * stuff is passed to shell commands and environment vars)
+		 */
+		while( *p != '\0' )
+		{ 
+		    if ( *p == '\'' || *p == '\"' || !isprint(*p) ) *p = ' ';
+		    p++;
+		}
 	    }
 	    lprintf(L_JUNK, "CND: found: %s", *(cp->variable));
 	    return;
@@ -263,6 +278,7 @@ int cnd_call _P3((name, tty, dist_ring),
 
     program = malloc( strlen(name) + strlen(tty) + 
 		      strlen( CallerId ) + strlen( CalledNr ) +
+		      strlen( CallName ) +
 		      sizeof( CONSOLE ) + 50 );
     if ( program == NULL )
 	    { lprintf( L_ERROR, "cnd_call: can't malloc" ); return 0; }
