@@ -1,4 +1,4 @@
-#ident "$Id: conf_mg.c,v 4.15 2001/01/27 16:22:37 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: conf_mg.c,v 4.18 2005/12/30 21:41:07 gert Exp $ Copyright (c) Gert Doering"
 
 /* conf_mg.c
  *
@@ -23,10 +23,6 @@ extern char * mgetty_version;		/* mgetty.c/version.h */
 # define MODEM_CHECK_TIME -1		/* no check */
 #endif
 
-#if defined(FAX_USRobotics) && !defined(FAX_RECV_SWITCHBD)
-#define FAX_RECV_SWITCHBD 19200
-#endif
-
 #ifndef FAX_RECV_SWITCHBD
 #define FAX_RECV_SWITCHBD 0		/* no switching */
 #endif
@@ -106,6 +102,7 @@ struct conf_data_mgetty c = {
 	{ "login-time", {0}, CT_INT, C_EMPTY },
 #endif
 	{ "fido-send-emsi", {TRUE}, CT_BOOL, C_PRESET },
+	{ "login-env-ttyprompt-hack", {FALSE}, CT_BOOL, C_PRESET },
 
 #ifdef LOGIN_CFG_FILE
 	{ "login-conf-file", {(p_int) LOGIN_CFG_FILE}, CT_STRING, C_PRESET },
@@ -121,7 +118,7 @@ struct conf_data_mgetty c = {
 #ifdef MAIL_TO
 	{ "notify", {(p_int)MAIL_TO}, CT_STRING, C_PRESET },
 #else
-	{ "notify", {0, CT_STRING}, C_EMPTY },
+	{ "notify", {0}, CT_STRING, C_EMPTY },
 #endif
 	{ "fax-owner", {(p_int)FAX_IN_OWNER}, CT_STRING, C_PRESET },
 #ifdef FAX_IN_GROUP
