@@ -1,4 +1,4 @@
-#ident "$Id: faxlib.c,v 4.65 2006/01/01 17:09:09 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.74 2007/02/06 17:04:13 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
@@ -7,6 +7,17 @@
  *
  * Only class 2 and class 2.0 stuff is here. Class 1 stuff is so
  * different that it goes to a separate library.
+ *
+ * $Log: faxlib.c,v $
+ * Revision 4.74  2007/02/06 17:04:13  gert
+ * fix modem ID stuff for Blatzheim
+ *
+ * Revision 4.73  2007/02/06 16:26:07  gert
+ * grab FW version number for Blatzheim modems
+ *
+ * Revision 4.72  2006/11/03 13:08:50  gert
+ * add CVS tag
+ *
  */
 
 #include <stdio.h>
@@ -120,6 +131,13 @@ int  ix;
 	    fwf_copy_remote_id( &line[ix] );
 	}
 
+	else if ( strncmp( line, "+FNSF:", 6 ) == 0 || 	/* class 2 */
+		  strncmp( line, "+FNF:", 5 ) == 0 ||	/* class 2.0 */
+		  strncmp( line, "FNF:", 4 ) == 0 )	/* USR bug */
+	{
+	    fax2_incoming_nsf( &line[ix] );
+	}
+
 	else if ( strncmp( line, "+FDCS:", 6 ) == 0 ||
 		  strncmp( line, "+FCS:", 5 ) == 0 )
 	{
@@ -449,8 +467,6 @@ unsigned char fax_send_swaptable[256];
 unsigned char fax_recv_swaptable[256];
 
 /* set up bit swap table */
-
-static 
 void fax_init_swaptable _P2( (direct, byte_tab),
 			      int direct, unsigned char byte_tab[] )
 {
@@ -499,6 +515,63 @@ int fax_set_bor _P2( (fd, bor), int fd, int bor )
     return mdm_command( buf, fd );
 }
 
+/* parse NSF (non-standard frames) - like "remote vendor ID", etc.
+ *
+ * class 2/2.0 deliver NSFs like this: "+FNF:86 40 40 FF 06 42 86 40 40",
+ * while class 1 just delivers a binary frame.
+ * -> convert to binary, pass on to class 1 handler
+ *
+ * (some modems deliver "+FNF:0000090008...", so we accept about anything
+ * that looks like "pairs of hex digits with or without separators")
+ */
+#define char_to_hex(ch) ( ( (ch)>='0' && (ch)<='9')? (ch)-'0' : \
+				tolower((ch))-'a'+10 )
+void fax2_incoming_nsf _P1((nsf_hex), char * nsf_hex )
+{
+#ifdef FAX_NSF_PARSER
+uch nsf_bin[200];
+int len;
+char *p;
+
+    len = 0;
+    p = nsf_hex;
+    /* some modems insert extra quotes at the start... (ZyXEL) */
+    while( *p != '\0' && ! isxdigit(*p) ) p++;
+
+    while( len<sizeof(nsf_bin) && isxdigit(*p) && isxdigit(*(p+1)) )
+    {
+	nsf_bin[len++] = (uch) ( char_to_hex(*p) << 4 ) +
+					char_to_hex(*(p+1));
+	p+=2;
+	while( *p != '\0' && ! isxdigit(*p) ) p++;
+    }
+
+    fax1_incoming_nsf( nsf_bin, len );
+#endif
+}
+
+void fax1_incoming_nsf _P2((nsf_bin, len), uch * nsf_bin, int len)
+{
+#ifdef FAX_NSF_PARSER
+char nsf_print[200];
+int i;
+
+    /* normal bit order */
+    for(i=0;i<len && i<sizeof(nsf_print);i++)
+	nsf_print[i] = isprint(nsf_bin[i])? nsf_bin[i]: '.';
+    nsf_print[i] = '\0';
+
+    lprintf( L_NOISE, "NSF(%02d): %s", len, nsf_print );
+
+    for(i=0;i<len && i<sizeof(nsf_print);i++)
+	nsf_print[i] = isprint(fax_send_swaptable[nsf_bin[i]])? 
+				fax_send_swaptable[nsf_bin[i]]: '.';
+    lprintf( L_NOISE, "    rev: %s", nsf_print );
+
+    hylafax_nsf_decode( nsf_bin, len );
+#endif
+}
+
 
 /* find out the type of modem connected
  *
@@ -912,6 +985,12 @@ int mdm_identify _P1( (fd), int fd )
 	    lprintf( L_MESG, "possibly Siemens GSM modem?  assuming class 2" );
 	    modem_type=Mt_class2;
 	}
+	else if ( strncmp( l, "BM-33k6/ISDN pro", 16 ) == 0 )	/* gert */
+	{
+	    lprintf( L_MESG, "Blatzheim ISDN modem, buggy class 2.0, force class 2" );
+	    modem_type=Mt_class2;
+	    mis = mdm_get_idstring( "ATI3", 1, fd );
+	}
     }
 
     if ( mis != NULL ) 
