@@ -1,4 +1,4 @@
-#ident "$Id: mgetty.c,v 4.36 2003/11/17 19:08:20 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: mgetty.c,v 4.40 2005/12/31 15:54:01 gert Exp $ Copyright (c) Gert Doering"
 
 /* mgetty.c
  *
@@ -7,6 +7,15 @@
  * some parts of the code (lock handling, writing of the utmp entry)
  * are based on the "getty kit 2.0" by Paul Sutcliffe, Jr.,
  * paul@devon.lns.pa.us, and are used with permission here.
+ *
+ * $Log: mgetty.c,v $
+ * Revision 4.40  2005/12/31 15:54:01  gert
+ * correctly handle non-adaptive fax answer in class 1/1.0 mode (modem will
+ * send "CONNECT", meaning "I'm in fax mode, please send DIS frame"...)
+ *
+ * Revision 4.39  2005/11/24 17:00:30  gert
+ * add CVS Log keyword
+ *
  */
 
 #include <stdio.h>
@@ -68,7 +77,7 @@ time_t		time _PROTO(( time_t * tloc ));
 /* logname.c */
 int getlogname _PROTO(( char * prompt, TIO * termio,
 		char * buf, int maxsize, int max_login_time, 
-		boolean do_fido ));
+		boolean do_fido, boolean env_ttyprompt ));
 
 /* conf_mg.c */
 void exit_usage _PROTO((int num));
@@ -867,6 +876,20 @@ Ring_got_action:
 		rmlocks();
 		exit(1);
 	    }
+#ifdef CLASS1
+	    /* in fax class 1, without adaptive answer, the sequence 
+	     * "ATA...CONNECT" means "we're in fax mode" - and it means
+	     * that the fax1 receiver must not wait for CONNECT, because
+	     * it's already there.  Boy, is this ugly...
+	     */
+	    if ( c_bool(fax_only) &&
+		 ( modem_type == Mt_class1 || modem_type == Mt_class1_0 ))
+	    {
+		fax1_receive_have_connect = TRUE;
+		mgetty_state = St_incoming_fax;
+		break;
+	    }
+#endif
 
 	    /* some (old) modems require the host to change port speed
 	     * to the speed returned in the CONNECT string, usually
@@ -1035,7 +1058,7 @@ Ring_got_action:
 
 	if ( getlogname( c_string(login_prompt), &tio, buf, sizeof(buf), 
 			 c_bool(blocking)? 0: c_int(login_time), 
-			 c_bool(do_send_emsi) ) == -1 ) 
+			 c_bool(do_send_emsi), c_bool(env_ttyprompt) ) == -1 ) 
 	{
 	     continue;
 	}
@@ -1046,9 +1069,7 @@ Ring_got_action:
 	/* dreadful hack for Linux, set TERM if desired */
 	if ( c_isset(termtype) )
 	{
-	    char * t = malloc( 6 + strlen( c_string(termtype)) );
-	    if ( t != NULL )
-	        { sprintf( t, "TERM=%s", c_string(termtype) ); putenv(t); }
+	    set_env_var( "TERM", c_string(termtype) );
 	}
 
 	/* catch "standard question #29" (DCD low -> /bin/login gets stuck) */
