@@ -14,7 +14,7 @@
  * Removed most stuff from this file, since the new IS-101 driver can be
  * used now. (Marc 04.01.1997)
  *
- * $Id: Rockwell.c,v 1.9 2000/12/16 10:58:15 marcs Exp $
+ * $Id: Rockwell.c,v 1.11 2006/09/26 17:17:56 gert Exp $
  *
  */
 
@@ -45,7 +45,7 @@ static int Rockwell_init(void)
      reset_watchdog();
      lprintf(L_MESG, "initializing ROCKWELL voice modem");
      voice_modem_state = INITIALIZING;
-     sprintf(buffer, "AT#VSP=%1u", cvd.rec_silence_len.d.i);
+     sprintf(buffer, "AT#VSP=%1u", (int)cvd.rec_silence_len.d.i);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "can't set silence period");
@@ -59,7 +59,7 @@ static int Rockwell_init(void)
 	if (cvd.transmit_gain.d.i == -1) {
 	   cvd.transmit_gain.d.i = 50;
 	}
-        sprintf(buffer, "AT#TL=%X", (65536 / (100 / cvd.transmit_gain.d.i)));
+        sprintf(buffer, "AT#TL=%X", (65536 / (100 / (int)cvd.transmit_gain.d.i)));
 
 	if (voice_command(buffer, "OK") != VMA_USER_1) {
           lprintf(L_WARN, "can't set transmit gain");
@@ -70,7 +70,7 @@ static int Rockwell_init(void)
 	if (cvd.receive_gain.d.i == -1) {
 	   cvd.receive_gain.d.i = 50;
 	}
-        sprintf(buffer, "AT#RG=%X", (65536 / (100 / cvd.receive_gain.d.i)));
+        sprintf(buffer, "AT#RG=%X", (65536 / (100 / (int)cvd.receive_gain.d.i)));
 
 	if (voice_command(buffer, "OK") != VMA_USER_1) {
 	     lprintf(L_WARN, "can't set record gain");
@@ -90,7 +90,7 @@ static int Rockwell_init(void)
           return(ERROR);
           }
 
-     sprintf(buffer, "AT#VSS=%1u", cvd.rec_silence_threshold.d.i * 3 / 100);
+     sprintf(buffer, "AT#VSS=%1u", (int)cvd.rec_silence_threshold.d.i * 3 / 100);
 
      if (voice_command(buffer, "OK") != VMA_USER_1)
           lprintf(L_WARN, "can't set silence threshold");
@@ -109,7 +109,7 @@ static int Rockwell_init(void)
      return(OK);
      }
 
-static int Rockwell_set_compression (int *compression, int *speed, int *bits)
+static int Rockwell_set_compression (p_int *compression, p_int *speed, int *bits)
      {
      reset_watchdog();
 
@@ -252,6 +252,13 @@ voice_modem_struct Rockwell =
      (char *) Rockwell_play_dtmf_cmd,
      (char *) IS_101_play_dtmf_extra,
      (char *) IS_101_play_dtmf_answr,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     NULL,  /* (char *) V253modem_start_duplex_voice_cmnd, */
+     NULL,  /* (char *) V253modemstart_duplex_voice_answr, */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_cmnd , */
+     NULL,  /* (char *) V253modem_stop_duplex_voice_answr, */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
+
      &IS_101_answer_phone,
      &IS_101_beep,
      &IS_101_dial,
@@ -276,6 +283,10 @@ voice_modem_struct Rockwell =
      &IS_101_wait,
      &IS_101_play_dtmf,
      &IS_101_check_rmd_adequation,
+     // juergen.kosel@gmx.de : voice-duplex-patch start
+     &IS_101_handle_duplex_voice,
+     NULL, /* since there is no way to enter duplex voice state */
+     // juergen.kosel@gmx.de : voice-duplex-patch end
      0
      };
 
