@@ -4,7 +4,7 @@
  * Try all available voice devices and open the first one that
  * suceeds and initialize it.
  *
- * $Id: open.c,v 1.4 1998/09/09 21:07:32 gert Exp $
+ * $Id: open.c,v 1.7 2002/02/25 12:19:57 gert Exp $
  *
  */
 
@@ -46,7 +46,7 @@ int voice_open_device(void)
 
                if ((voice_fd = open(voice_tty, O_RDWR | O_NDELAY | O_NOCTTY)) == FAIL)
                     {
-                    lprintf(L_WARN, "error opening %s", voice_tty);
+                    lprintf(L_ERROR, "error opening %s", voice_tty);
                     rmlocks();
                     voice_fd = NO_VOICE_FD;
                     }
@@ -61,8 +61,13 @@ int voice_open_device(void)
 
      if (voice_fd != NO_VOICE_FD)
           {
-          DevID = malloc(strlen(voice_tty) + 1);
-          strcpy(DevID, voice_tty);
+	  char * p = voice_tty;
+	  if ( strncmp( p, "/dev/", 5 ) == 0 ) p+=5;
+
+          DevID = malloc(strlen(p) + 1);
+          strcpy(DevID, p);
+	  for( p=DevID; *p; p++) if (*p == '/') *p='-';
+
           lprintf(L_MESG, "reading port %s configuration from config file %s",
            &voice_tty[5], voice_config_file);
           get_config(voice_config_file, (conf_data *) &cvd, "port",
