@@ -3,8 +3,11 @@
  *
  * Installs the signal handlers for the voice code and contains the
  * signal handler functions.
+ * BUGS
+ *    - Something I do not like is that it looks like we use non
+ *      reentrant functions in the signal handlers (log, etc).
  *
- * $Id: signal.c,v 1.4 1998/09/09 21:07:36 gert Exp $
+ * $Id: signal.c,v 1.8 1999/10/09 20:13:04 marcs Exp $
  *
  */
 
@@ -31,8 +34,23 @@ static void signal_sigalrm(int sig)
 
 static void signal_sigchld(int sig)
      {
+     pid_t pid;
+     int status;
+     pid = wait(&status); /* This appears to fix core dumps on HPUX. Maybe this
+                           * also fixes the same problem on Solaris.
+                           */
      signal(SIGCHLD, signal_sigchld);
-     lprintf(L_JUNK, "%s: Got child changed status signal", program_name);
+     if (status) {
+        lprintf(L_WARN, "%s: Got child %d exit status %d signal",
+                program_name,
+                pid,
+                status);
+     }
+     else {
+        lprintf(L_JUNK, "%s: Got child %d exit signal",
+                program_name,
+                pid);
+     }
      queue_event(create_event(SIGNAL_SIGCHLD));
      }
 
